/* *************************************************************************
   program configuration
   here you can configure your GPIOs and some default values
   Variant ESP32: a variant using an ESP32 8 channel Relay Board (https://werner.rothschopf.net/microcontroller/202208_esp32_relay_x8_en.htm)
                  Relays are active HIGH
                  No fency webserver. Just a plain antenna switch
   Remark:        as of 2022-11-26 this is NOT tested in production (only on the workbench)
   ************************************************************************* */

constexpr uint8_t relayON {HIGH};                // if you are using inverse logic to activate (digitalWrite(n, LOW)) set relayON to LOW
constexpr uint8_t relayOFF {LOW};                // obviously, this should be invers of the above line

constexpr uint8_t lcdAddr {0x3F};                // I2C address for LCD display - most common are 0x27 or 0x3F - if it is not working, check the address with an I2C scanner-

//#define FILTER_TO   0x00                       // to address 00 = broadcast
#define FILTER_FROM 0x94                         // from address (e.g. the transmitter sending the QRG)

#define DEBUG                                    // activate/uncomment if you want to follow what the code is doing on the serial monitor
#define USE_SERIAL 2                             // 0 .. 3 Serial. default on ESP32 is 2 (on pins 16/17) (don't use -1 as Software Serial is not necessary (and sometimes poorly working) on ESP32)
#define USE_CIV 1                                // set to 1 if you want to use CI-V interface 

constexpr uint8_t tonePin      {4};              // GPIO for buzzer
//constexpr uint8_t catRxPin  {16};              // reserved for soft serial; on ESP32 pin 16 is Rx2
//constexpr uint8_t catTxPin  {17};              // reserved for soft serial; on ESP32 pin 17 is Tx2
//                            {23};              // internal LED; on the relay board there is a LED on pin 23
constexpr uint8_t leftPin     {19};              // GPIO for "left" pin (decrease), connect button to ground
constexpr uint8_t rightPin    {5};               // GPIO for "right" pin (increase), connect button to ground
// constexpr uint8_t bandPin  {23};              // GND - 4K7 - AnalogIn - 4K7 - Band signal from ACC socket (don't use this on ESP32)
// constexpr uint8_t txSimPin {23};              // not used in this version
constexpr uint8_t pttPin      {18};              // GPIO for the PTT
// 21                                            // used as SDA for I2C LCD
// 22                                            // used as SCL for I2C LCD

Antenna antenna[] {
  //pin 12345678
  {32,  "Ant A   "},                              // GPIO Relay A
  {33,  "Ant B   "},                              // GPIO Relay B
  {25,  "Ant C   "},                              // GPIO Relay C
  {26,  "Ant D   "},                              // GPIO Relay D
  {27,  "Ant E   "},                              // GPIO Relay E
  {14,  "Ant F   "},                              // GPIO Relay F
  {12,  "Ant G   "},                              // GPIO Relay G
  {13,  "Ant H   "}                               // GPIO Relay H
};
constexpr size_t noOfAntenna(sizeof(antenna) / sizeof(antenna[0]));      // calculate the number of elements

Bandinformation tblBandinformation[] {
  {  471,   480,     "630 "},
  // { 1760,  2050,  "160 "},                     // full band
  { 1760,  1859,     "160A"},                     // example how you could split a band individually
  { 1860,  2050,     "160B"},                     // example how you could split a band individually
  // { 3475,  3850,  " 80"},                      // full band
  { 3475,  3699,     "80A "},
  { 3700,  3850,     "80B "},
  { 5325,  5380,     " 60 "},                     // you could write 60m, but you need enough space on the LCD!
  { 6975,  7450,     " 40 "},
  {10075, 10175,     " 30 "},
  {13975, 14375,     " 20 "},
  {18018, 18200,     " 17 "},
  {20975, 21457,     " 15 "},
  {24840, 25040,     " 12 "},
  {27975, 29750,     " 10 "},
  {49975, 52025,     " 6m "},
  {69975, 71025,     " 4m "},
  {144000, 146999,   " 2m "},
  {430000, 440999,   "70cm"},
  {1240000, 1300999, "23cm"},
  {2320000, 2450999, "13cm"},
  {3400000, 3475999, " 9cm"},
  {5650000, 5850000, " 6cm"}
};
constexpr size_t noOfBand = sizeof(tblBandinformation) / sizeof(tblBandinformation[0]);      // calculate the number of elements

struct {                                         // this (anonym) structur holds user settings which should be persisted in the EEPROM
  int8_t antennaStart {0};                       // start with this antenna till first received QRG, use -1 if no antenna after startup (all relais off)
  uint8_t keyBeep {20};                          // beep in milliseconds on keystroke. 0 no beep. Default 20.
  uint8_t antennaRX[noOfBand];                   // we will store one antenna definition for each band
} setting;
