/* *************************************************************************
   program configuration
   here you can configure your GPIOs and some default values
   Variant Y: YAESU RS232 (used with a YAESU FTDX101MP)
   PROTOTYPE - unfortunately I wasn't able to test the code 
   ************************************************************************* */

constexpr uint8_t relayON {LOW};                 // if you are using inverse logic to activate (digitalWrite(n, LOW)) set relayON to LOW
constexpr uint8_t relayOFF {HIGH};               // obviously, this should be invers of the above line

constexpr uint8_t lcdAddr {0x3F};                // I2C address for LCD display - most common are 0x27 or 0x3F - if it is not working, check the address with an I2C scanner-

#define DEBUG                                    // activate/uncomment if you want to follow what the code is doing on the serial monitor
#define USE_SERIAL -1                            // 0 .. 3 Serial, set to -1 to use Software Serial (default)
#define USE_YAESU_RS232 1                        // set to 1 if you want tu use the YAESU interface

constexpr uint8_t tonePin     {11};              // GPIO for buzzer (default 11)
constexpr uint8_t catRxPin    {12};              // used for soft serial (default 12);
constexpr uint8_t catTxPin    {10};              // reserved for soft serial TX - used in case of YAESU protocol
//                   13;                         // internal LED
constexpr uint8_t leftPin     {A0};              // GPIO for "left" pin (decrease), connect button to ground. Default A0
constexpr uint8_t rightPin    {A1};              // GPIO for "right" pin (increase), connect button to ground. Default A1
#if USE_ADC
// constexpr uint8_t bandPin  {A2};              // GND - 4K7 - AnalogIn - 4K7 - Band signal from ACC socket
#endif
// constexpr uint8_t txSimPin {A2};              // not used in this version (default A2)
constexpr uint8_t pttPin      {A3};              // GPIO for the PTT (default A3)
// A4                                            // used as SDA for I2C LCD
// A5                                            // used as SCL for I2C LCD

Antenna antenna[] {
  //pin 12345678
  {2,  "Ant A   "},                              // GPIO Relay A
  {3,  "Ant B   "},                              // GPIO Relay B
  {4,  "Ant C   "},                              // GPIO Relay C
  {5,  "Ant D   "},                              // GPIO Relay D
  {6,  "Ant E   "},                              // GPIO Relay E
  {7,  "Ant F   "},                              // GPIO Relay F
  {8,  "Ant G   "},                              // GPIO Relay G
  {9,  "Ant H   "}                               // GPIO Relay H
};
constexpr size_t noOfAntenna(sizeof(antenna) / sizeof(antenna[0]));      // calculate the number of elements

Bandinformation tblBandinformation[] {
  {  471,   480,     "630 "},
  // { 1760,  2050,  "160 "},                    // full band
  { 1760,  1859,     "160A"},                    // example how you could split a band individually
  { 1860,  2050,     "160B"},                    // example how you could split a band individually
  // { 3475,  3850,  " 80"},                     // full band
  { 3475,  3699,     "80A "},
  { 3700,  3850,     "80B "},
  { 5325,  5380,     " 60 "},                    // you could write 60m, but you need enough space on the LCD!
  { 6975,  7450,     " 40 "},
  {10075, 10175,     " 30 "},
  {13975, 14375,     " 20 "},
  {18018, 18200,     " 17 "},
  {20975, 21457,     " 15 "},
  {24840, 25040,     " 12 "},
  {27975, 29750,     " 10 "},
  {49975, 52025,     " 6m "},
  {69975, 71025,     " 4m "},
  {144000, 146999,   " 2m "},
  {430000, 440999,   "70cm"},
  {1240000, 1300999, "23cm"},
  {2320000, 2450999, "13cm"},
  {3400000, 3475999, " 9cm"},
  {5650000, 5850000, " 6cm"}
};

constexpr size_t noOfBand = sizeof(tblBandinformation) / sizeof(tblBandinformation[0]);      // calculate the number of elements

struct {                                         // this (anonym) structur holds user settings which should be persisted in the EEPROM
  int8_t antennaStart {0};                       // start with this antenna till first received QRG, use -1 if no antenna after startup (all relais off)
  uint8_t keyBeep {20};                          // beep in milliseconds on keystroke. 0 no beep. Default 20.
  uint8_t antennaRX[noOfBand];                   // we will store one antenna definition for each band
} setting;
