/* *************************************************************************
   program configuration
   here you can configure your GPIOs and some default values
   Variant YAESU linear: read binary code from 4 pins on the YAESU Linear Jack
   2023-08-16            also used for "Lois" in production
   ************************************************************************* */

constexpr uint8_t relayON {LOW};                 // if you are using inverse logic to activate (digitalWrite(n, LOW)) set relayON to LOW
constexpr uint8_t relayOFF {HIGH};               // obviously, this should be invers of the above line

constexpr uint8_t lcdAddr {0x3F};                // I2C address for LCD display - most common are 0x27 or 0x3F - if it is not working, check the address with an I2C scanner-

#define DEBUG                                    // activate/uncomment if you want to follow what the code is doing on the serial monitor
#define USE_SERIAL 0                             // 0 .. 3 Serial, set to -1 to use Software Serial. For YAESU linear you can't use Softserial. Set it to 0
#define USE_YAESU_LINEAR 1                       // set to 1 if you want to the YAESU linear socket

constexpr uint8_t tonePin     {11};              // GPIO for buzzer (default 11)
constexpr uint8_t leftPin     {A0};              // GPIO for "left" pin (decrease), connect button to ground. Default A0
constexpr uint8_t rightPin    {A1};              // GPIO for "right" pin (increase), connect button to ground. Default A1
// constexpr uint8_t txSimPin {A2};              // not used in this version (but A2 is used for band reading)
constexpr uint8_t pttPin      {A3};              // GPIO for the PTT (default A3)
// A4                                            // used as SDA for I2C LCD
// A5                                            // used as SCL for I2C LCD

constexpr uint8_t linearPin[] {10, 12, 13, A2};  // the 4 data pins to read the binary information on the YAESU Linear Jack

Antenna antenna[] {
  //pin 12345678
  {2,  "Ant A   "},                              // GPIO Relay A
  {3,  "Ant B   "},                              // GPIO Relay B
  {4,  "Ant C   "},                              // GPIO Relay C
  {5,  "Ant D   "},                              // GPIO Relay D
  {6,  "Ant E   "},                              // GPIO Relay E
  {7,  "Ant F   "},                              // GPIO Relay F
  {8,  "Ant G   "},                              // GPIO Relay G
  {9,  "Ant H   "}                               // GPIO Relay H
};
constexpr size_t noOfAntenna(sizeof(antenna) / sizeof(antenna[0]));      // calculate the number of elements

// keep the table bandinformation with the default values even though there are only bitcodes till 70cm
Bandinformation tblBandinformation[] {
  {  471,   480,     "630m"},
  { 1760,  2050,     "160m"},                    
  { 3475,  3850,     " 80m"},                    
  { 5325,  5380,     " 60m"},                    
  { 6975,  7450,     " 40m"},
  {10075, 10175,     " 30m"},
  {13975, 14375,     " 20m"},
  {18018, 18200,     " 17m"},
  {20975, 21457,     " 15m"},
  {24840, 25040,     " 12m"},
  {27975, 29750,     " 10m"},
  {49975, 52025,     " 6m "},
  {69975, 71025,     " 4m "},
  {144000, 146999,   " 2m "},
  {430000, 440999,   "70cm"},
  {1240000, 1300999, "23cm"},
  {2320000, 2450999, "13cm"},
  {3400000, 3475999, " 9cm"},
  {5650000, 5850000, " 6cm"}
};

constexpr size_t noOfBand = sizeof(tblBandinformation) / sizeof(tblBandinformation[0]);      // calculate the number of elements

struct {                                         // this (anonym) structur holds user settings which should be persisted in the EEPROM
  uint8_t keyBeep {20};                          // beep in milliseconds on keystroke. 0 no beep. Default 20.
  uint8_t antennaRX[noOfBand];                   // we will store one antenna definition for each band
  int8_t antennaStart {0};                       // start with this antenna till first received QRG, use -1 if no antenna after startup (all relais off)
} setting;
