/* *************************************************************************
   Input Interface for ICOM - ACC Socket
   (ADC Measurement to Freqency)

   To keep the rest of the code compatible the ACC flow is done like following

   The get function reads the ADC.
   The ADC is mapped with a table ("from - to values") to QRG
   This QRG can be used in the rest of the code like readed from the rig
   
   ************************************************************************* */


#if USE_ADC

/*
   Read QRG from ACC socket pin 5 via ADC
   If it is a new ADC value which causes a frequency change, return the frequency
   This keeps track of the current frequency and only
   returns a value != 0 when the frequency has changed
*/
unsigned long getFrequencyAdc(void) {
  uint32_t t_QRG = 0;                            // QRG100 variable stores frequency in GMMMkkkH format - Frequency divided by 100
  static unsigned long lastfreq = 0;             // highest QRG100 in 32 bit: 4.294.967.295 --> 429 GHz (!)
  static uint32_t previousMillis = 0;
  if (millis() - previousMillis > 500) {
    previousMillis = millis();
    uint16_t raw = 0;
    analogRead(bandPin);       // throw away first measurement
    for (uint8_t i = 0; i < 5; i++) {
      raw += analogRead(bandPin);
    }
    raw = raw / 5;
    previousAdc = raw;         // used later on to print ADC to display
    t_QRG = adc2qrg(raw) * 10; // this is only to be compatible to the CI-V interface
    //DEBUG_PRINT(F("D518 ADC=")); DEBUG_PRINT(raw); DEBUG_PRINT(F("\tt_QRG=")); DEBUG_PRINTLN(t_QRG);
    if (t_QRG == lastfreq) {
      indicatorActivity.on();  // tbc ... pseudo activity
      return (0);              // but exit if it is the same
    }
    DEBUG_PRINT(F("D524 ADC=")); DEBUG_PRINT(raw); DEBUG_PRINT(F("\tt_QRG=")); DEBUG_PRINTLN(t_QRG);
    lastfreq = t_QRG;
    return (t_QRG);
  }
  return (0); // no measurement
}

// get QRG from ADC value
uint32_t adc2qrg(const uint16_t adc) {
  constexpr uint8_t noOfAdc = sizeof(tblAdcBandinformation) / sizeof(tblAdcBandinformation[0]);
  for (uint8_t i = 0; i < noOfAdc; i++) {
    if (adc >= tblAdcBandinformation[i].adcLow && adc <= tblAdcBandinformation[i].adcHigh) return tblAdcBandinformation[i].qrg;
  }
  return 0;
}
#endif
