/* *************************************************************************
   Input Interface for YAESU RS232 - FTDX101MP
   Reads from the RS232 Interface
   ASCII
   Protokol
   two start bytes (= the command)
   variable length payload
   end tag ;
  // 0 is command
  // 1 is command
  // n payload
  // n+1 ; The End-Tag

   2023-08-13 PROTOTYPE - unfortunately I wasn't able to test the code
   ************************************************************************* */

#if USE_YAESU_RS232

// initialise the rig
void yaesuBegin(){
  while (mySerial.available()) mySerial.read();           // empty buffer
  mySerial.print(F("AI1;"));                              // Auto Information On (1)
  mySerial.print(F("FA;"));                               // Frequency Main Band (request first QRG)
}

// re-initialise time by time
// as alternative you could ask for FA; in case the connection timeout happens
void yeasuTimer(uint32_t currentMillis = millis()) {
  static uint32_t previousMillis = 0;
  if (currentMillis - previousMillis > 30000UL) {
    yaesuBegin();
  }
}

/*
   Decode a message from a YAESU rig.
   If it is a frequency message, return the frequency
   This keeps track of the current frequency and only
   returns a value != 0 when the frequency has changed
   reads message bytewise (one byte per call)
   returns 0 (no new QRG or still reading)
           or the QRG100 (if reading was sucessfull)
*/
unsigned long yaesuGetFrequency(void) {
  unsigned char c;                    // incoming character
  uint32_t t_QRG = 0;                 // QRG100 variable stores frequency in GMMMkkkH format - frequence divided by 100
  //uint8_t GHZ = 0, MHZ = 0, KHZ = 0, HZ = 0;
  static char buffget[16];   // read buffer
  static int8_t idx = 0;              // index/counter of actual position
  static unsigned long lastfreq = 0;  // highest QRG100 in 32 bit: 4.294.967.295 --> 429 GHz (!)

  // If there's no input character return
  if (mySerial.available() <= 0) return (0);
  // If we haven't found an end of message, reset and try again.
  if (idx >= 15) {
    idx = 0;
    DEBUG_PRINTLN(F("D037 to long NOK"));
    return (0);
  }
  // Read the character
  c = buffget[idx] = mySerial.read();

  // check for the end tag: When not ; leave function
  if (c != ';') {
    idx++;
    return (0);
  }
#ifdef DEBUG
  for (int j = 0; j <= idx; j++) {
    Serial.write(buffget[j]);
  }
  Serial.println();
#endif
  //uint8_t len = idx;  // we destroy idx in next step but we need the received length later also
  idx = 0;
  // There is a complete message in buffget
  // If it is not a frequency message, ignore it
  // 0 is command
  // 1 is command
  // n payload
  // n+1 ; The End-Tag
  if (buffget[0] == 'F' || buffget[1] == 'A') {
    DEBUG_PRINTLN(F("D056 FA"));
    // parse QRG
    t_QRG = strtoul(buffget + 2, NULL, 10) / 100; // QRG100 variable stores frequency in GMMMkkkH format - Frequency divided by 100
    previousQRGreceived = millis();               // we have received a valid QRG (so offline indicator might get resetted)
    indicatorOffline.off();
    if (t_QRG == lastfreq) {
      indicatorActivity.on();
      return (0);  // but exit if it is the same
    }
    lastfreq = t_QRG;
    return (t_QRG);
  }
  return(0); // should not be necessary but lets keep it to have a nice end of the function
}

#endif
